==> xmonad-extras-0.17.2-145-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-LHnVpFJMKqtLdD7MKeMalr
key:                  xmonad-extras-0.17.2-LHnVpFJMKqtLdD7MKeMalr
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  12dba05bc7ab17ec9bea003a7c1c0ff7
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-LHnVpFJMKqtLdD7MKeMalr
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-DxwQecE0J4QHGHdMDtxYGB
    hint-0.9.0.8-4bzCs0L8a2y1YyKIH5fOJI
    libmpd-0.10.0.1-BVx55eHM2672E7QVXMBj3J mtl-2.2.2
    network-3.1.4.0-BMQQjwbPvFR57Ka0tgIiy2
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-GLF9DtFf0xA137oEkCMUf9
    xmonad-contrib-0.18.1-Kkr0ZKcbQyG9co872xw8CW

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-166-riscv64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-1nXvrYIh0ok2ESWkus4Aoe
key:                  xmonad-extras-0.17.2-1nXvrYIh0ok2ESWkus4Aoe
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  a93a83988b3f92c95df7d08dd5ddc38a
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-1nXvrYIh0ok2ESWkus4Aoe
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.3-LpDQHaNyiML1MRcclv9sum
    hint-0.9.0.8-3x8RVjeWbJJJVRjHI7qg58
    libmpd-0.10.0.1-9OthOA6VlucIkGE4BiUSCd mtl-2.2.2
    network-3.1.4.0-2g2oEkgQCahBaM3HvlpVNW
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-CW2ThBsG6u778TpJuGrtuP
    xmonad-contrib-0.18.1-Ht9lqBJN05JHbPwtvwVWua

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
